Скрипты для аналитики скоринга
==============================

|GitHub|_
|ReadTheDocs|_
|TravisImage|_
|Coverage|_
|Pypi|_

В данном проекте содержится набор скриптов полезных в скоринге.

Установка
---------

Для установки воспользуйтесь pip::

    pip install risksutils


.. |TravisImage| image:: https://travis-ci.org/dshulchevskii/risksutils.svg?branch=master
.. _TravisImage: https://travis-ci.org/dshulchevskii/risksutils
.. |Coverage| image:: https://codecov.io/gh/dshulchevskii/risksutils/branch/master/graph/badge.svg
.. _Coverage: https://codecov.io/gh/dshulchevskii/risksutils
.. _ReadTheDocs: http://risksutils.readthedocs.io/ru/latest/?badge=latest
.. |ReadTheDocs| image:: https://readthedocs.org/projects/risksutils/badge/?version=latest
.. |GitHub| image:: https://img.shields.io/badge/github--green.svg
.. _GitHub: https://github.com/dshulchevskii/risksutils
.. |Pypi| image:: https://badge.fury.io/py/risksutils.svg
.. _Pypi: https://badge.fury.io/py/risksutils
